evaluate_rational

Function evaluate_rational 

pub fn evaluate_rational<P: Blend>(
    knots: &KnotVector,
    control: &[Weighted<P>],
    u: f64,
    tol: Tolerances,
) -> OgeomResult<P>
Evaluate a rational B-spline: de Boor in homogeneous coordinates, then divide through by the weight.

Errors

As evaluate, plus OgeomError::Numeric if the accumulated weight vanishes, which positive input weights make impossible.