split

Function split 

pub fn split<P: Blend>(
    knots: &KnotVector,
    control: &[P],
    u: f64,
    tol: Tolerances,
) -> OgeomResult<(Spline<P>, Spline<P>)>
Split a B-spline at u into two, each with its own clamped knot vector.

Works by raising the multiplicity at u to the degree, at which point the control points either side are already independent.

Errors

As insert_knot, plus OgeomError::Domain if u is at either end of the domain, where one half would be empty.