pub struct Ellipse2 { /* private fields */ }Expand description
An ellipse in the plane.
Implementations
Sourceimpl Ellipse2
impl Ellipse2
Sourcepub fn new(
frame: Frame2,
major_radius: f64,
minor_radius: f64,
tol: Tolerances,
) -> OgeomResult<Self>
pub fn new( frame: Frame2, major_radius: f64, minor_radius: f64, tol: Tolerances, ) -> OgeomResult<Self>
An ellipse with the given radii, the major radius along frame’s x.
Errors
OgeomError::Construction if a radius is
not finite and positive, or the minor exceeds the major.
Sourcepub const fn major_radius(&self) -> f64
pub const fn major_radius(&self) -> f64
The major radius.
Sourcepub const fn minor_radius(&self) -> f64
pub const fn minor_radius(&self) -> f64
The minor radius.
Sourcepub fn focal_distance(&self) -> f64
pub fn focal_distance(&self) -> f64
The distance from the centre to either focus.
Sourcepub fn eccentricity(&self) -> f64
pub fn eccentricity(&self) -> f64
The eccentricity, in [0, 1).
Sourcepub fn transformed(&self, t: &Transform2, tol: Tolerances) -> OgeomResult<Self>
pub fn transformed(&self, t: &Transform2, tol: Tolerances) -> OgeomResult<Self>