pub struct TangentCircle {
pub circle: Circle2,
pub placements: [Placement; 3],
}Expand description
One tangent circle, with its standing toward each target in order.
Fields
circle: Circle2The solution.
placements: [Placement; 3]How it stands to each target, in the order they were given.