hyperbola_parameter

Function hyperbola_parameter 

pub fn hyperbola_parameter(
    hyperbola: &Hyperbola,
    p: Point,
    tol: Tolerances,
) -> OgeomResult<f64>
The parameter of the point on a hyperbola in the direction of p.

Errors

OgeomError::Domain if p projects to the far branch, which this hyperbola does not describe.