torus_parameters

Function torus_parameters 

pub fn torus_parameters(
    torus: &Torus,
    p: Point,
    tol: Tolerances,
) -> OgeomResult<(f64, f64)>
The (u, v) of the point on a torus nearest p.

Errors

OgeomError::Construction if p lies on the axis, or on the tube’s centre circle where every v is equally near.