pub fn surface_derivatives<P: Blend>(
ku: &KnotVector,
kv: &KnotVector,
grid: &ControlGrid<P>,
u: f64,
v: f64,
order: usize,
tol: Tolerances,
) -> OgeomResult<DerivativeGrid<P>>Expand description
Evaluate a surface and its partial derivatives up to total order order.
result[k][l] is the derivative taken k times in u and l times in v,
so result[0][0] is the point itself.
Errors
As evaluate_surface.