pub fn lines_tangent_to_two_circles(
a: &Circle2,
b: &Circle2,
tol: Tolerances,
) -> Vec<Axis2>Expand description
The up-to-four lines tangent to two circles: the external pair where the circles lie on the same side, the internal pair where they straddle.