pub struct Axis2 {
pub location: Point2,
pub direction: Direction2,
}Expand description
A point and a direction in the plane.
Fields
location: Point2A point on the axis.
direction: Direction2The axis direction.
Implementations
Sourceimpl Axis2
impl Axis2
Sourcepub const fn new(location: Point2, direction: Direction2) -> Self
pub const fn new(location: Point2, direction: Direction2) -> Self
An axis from a point and a direction.
Sourcepub fn parameter_of(self, p: Point2) -> f64
pub fn parameter_of(self, p: Point2) -> f64
The parameter of the projection of p onto this axis.
Sourcepub fn signed_distance_to(self, p: Point2) -> f64
pub fn signed_distance_to(self, p: Point2) -> f64
The signed distance from p to this axis, positive on the left.
Sourcepub fn distance_to(self, p: Point2) -> f64
pub fn distance_to(self, p: Point2) -> f64
The distance from p to this axis.