pub struct Frame2 { /* private fields */ }Expand description
A local coordinate system in the plane.
Implementations
Sourceimpl Frame2
impl Frame2
Sourcepub const fn new(origin: Point2, x: Direction2) -> Self
pub const fn new(origin: Point2, x: Direction2) -> Self
A right-handed frame from an origin and a first axis.
Sourcepub fn from_axes(
origin: Point2,
x: Direction2,
y: Direction2,
tol: Tolerances,
) -> OgeomResult<Self>
pub fn from_axes( origin: Point2, x: Direction2, y: Direction2, tol: Tolerances, ) -> OgeomResult<Self>
A frame with an explicit second axis, whose handedness is inferred.
Errors
OgeomError::Construction if the two
axes are not perpendicular within tol.angular().
Sourcepub const fn x(&self) -> Direction2
pub const fn x(&self) -> Direction2
The first axis.
Sourcepub const fn y(&self) -> Direction2
pub const fn y(&self) -> Direction2
The second axis.
Sourcepub const fn handedness(&self) -> Handedness
pub const fn handedness(&self) -> Handedness
This frame’s handedness.
Sourcepub fn to_local(&self, p: Point2) -> Point2
pub fn to_local(&self, p: Point2) -> Point2
Local coordinates of a point given in world coordinates.
Sourcepub fn to_world(&self, p: Point2) -> Point2
pub fn to_world(&self, p: Point2) -> Point2
World coordinates of a point given in local coordinates.
Sourcepub fn vector_to_local(&self, v: Vector2) -> Vector2
pub fn vector_to_local(&self, v: Vector2) -> Vector2
Local components of a world-space vector.
Sourcepub fn vector_to_world(&self, v: Vector2) -> Vector2
pub fn vector_to_world(&self, v: Vector2) -> Vector2
World components of a vector given in local coordinates.