pub type DerivativeRows = SmallVec<[BasisValues; 4]>;Expand description
One row of basis values per derivative order, inline up to the jet orders the kernel asks for.
Aliased Type
pub struct DerivativeRows { /* private fields */ }pub type DerivativeRows = SmallVec<[BasisValues; 4]>;One row of basis values per derivative order, inline up to the jet orders the kernel asks for.
pub struct DerivativeRows { /* private fields */ }