pub struct Transform2 { /* private fields */ }Expand description
A similarity transform in the plane.
Implementations
Sourceimpl Transform2
impl Transform2
Sourcepub fn translation(v: Vector2) -> Self
pub fn translation(v: Vector2) -> Self
A translation.
Sourcepub fn line_mirror(origin: Point2, normal: Direction2) -> Self
pub fn line_mirror(origin: Point2, normal: Direction2) -> Self
Reflection in the line through origin with the given normal.
Sourcepub const fn kind(&self) -> TransformKind
pub const fn kind(&self) -> TransformKind
This transform’s classification.
Sourcepub const fn scale_factor(&self) -> f64
pub const fn scale_factor(&self) -> f64
The uniform scale factor. Negative for a point mirror.
Sourcepub const fn translation_vector(&self) -> Vector2
pub const fn translation_vector(&self) -> Vector2
The translation.
Sourcepub fn preserves_handedness(&self) -> bool
pub fn preserves_handedness(&self) -> bool
Whether this transform preserves handedness.
Sourcepub fn apply_direction(
&self,
d: Direction2,
tol: Tolerances,
) -> OgeomResult<Direction2>
pub fn apply_direction( &self, d: Direction2, tol: Tolerances, ) -> OgeomResult<Direction2>
Apply to a direction, renormalizing.
Errors
OgeomError::Construction if the result
cannot be normalized, which a valid similarity never produces.
Sourcepub fn apply_frame(&self, f: &Frame2, tol: Tolerances) -> OgeomResult<Frame2>
pub fn apply_frame(&self, f: &Frame2, tol: Tolerances) -> OgeomResult<Frame2>
Apply to a frame, transforming the origin and both axes.
Errors
OgeomError::Construction if the
transformed axes cannot be renormalized or are no longer perpendicular.
Sourcepub fn apply_vector(&self, v: Vector2) -> Vector2
pub fn apply_vector(&self, v: Vector2) -> Vector2
Apply to a free vector.